onDoubleTapDown property
A pointer that might cause a double tap has contacted the screen at a particular location.
Implementation
final GestureTapDownCallback? onDoubleTapDown;
A pointer that might cause a double tap has contacted the screen at a particular location.
final GestureTapDownCallback? onDoubleTapDown;