ClickableContainer class

A clickable container wrapped inside GestureDetector

Inheritance

Constructors

ClickableContainer({Key? key, Widget? child, double? width, double? height, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Color? color, Decoration? decoration, Decoration? foregroundDecoration, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, AlignmentGeometry? transformAlignment, Clip clipBehavior = Clip.none, GestureTapCallback? onTap, GestureTapUpCallback? onTapUp, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel, GestureTapCallback? onDoubleTap, GestureTapDownCallback? onDoubleTapDown, GestureTapCancelCallback? onDoubleTapCancel, GestureLongPressCallback? onLongPress, GestureLongPressDownCallback? onLongPressDown, GestureLongPressCancelCallback? onLongPressCancel, GestureLongPressStartCallback? onLongPressStart, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate})
const

Properties

alignment AlignmentGeometry?
Align the child within the container.
final
child Widget?
The container child widget
final
clipBehavior Clip
The clip behavior when Container.decoration is not null.
final
color Color?
The color to paint behind the child.
final
constraints BoxConstraints?
Additional constraints to apply to the child.
final
decoration Decoration?
The decoration to paint behind the child.
final
foregroundDecoration Decoration?
The decoration to paint in front of the child.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
The container height
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
Empty space to surround the decoration and child.
final
onDoubleTap GestureTapCallback?
The user has tapped the screen with a primary button at the same location twice in quick succession.
final
onDoubleTapCancel GestureTapCancelCallback?
The pointer that previously triggered onDoubleTapDown will not end up causing a double tap.
final
onDoubleTapDown GestureTapDownCallback?
A pointer that might cause a double tap has contacted the screen at a particular location.
final
onLongPress GestureLongPressCallback?
Called when a long press gesture with a primary button has been recognized.
final
onLongPressCancel GestureLongPressCancelCallback?
A pointer that previously triggered onLongPressDown will not end up causing a long-press.
final
onLongPressDown GestureLongPressDownCallback?
The pointer has contacted the screen with a primary button, which might be the start of a long-press.
final
onLongPressEnd GestureLongPressEndCallback?
A pointer that has triggered a long-press with a primary button has stopped contacting the screen.
final
onLongPressMoveUpdate GestureLongPressMoveUpdateCallback?
A pointer has been drag-moved after a long-press with a primary button.
final
onLongPressStart GestureLongPressStartCallback?
Called when a long press gesture with a primary button has been recognized.
final
onLongPressUp GestureLongPressUpCallback?
A pointer that has triggered a long-press with a primary button has stopped contacting the screen.
final
onTap GestureTapCallback?
A tap with a primary button has occurred.
final
onTapCancel GestureTapCancelCallback?
The pointer that previously triggered onTapDown will not end up causing a tap.
final
onTapDown GestureTapDownCallback?
A pointer that might cause a tap with a primary button has contacted the screen at a particular location.
final
onTapUp GestureTapUpCallback?
A pointer that will trigger a tap with a primary button has stopped contacting the screen at a particular location.
final
padding EdgeInsetsGeometry?
Empty space to inscribe inside the decoration. The child, if any, is placed inside this padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform Matrix4?
The transformation matrix to apply before painting the container.
final
transformAlignment AlignmentGeometry?
The alignment of the origin, relative to the size of the container, if transform is specified.
final
width double?
The container width
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited