onLongPressDown property

GestureLongPressDownCallback? onLongPressDown
final

The pointer has contacted the screen with a primary button, which might be the start of a long-press.

Implementation

final GestureLongPressDownCallback? onLongPressDown;