opacity property

Animation<double>? opacity
final

If non-null, the value from the Animation is multiplied with the opacity of each image pixel before painting onto the canvas.

Implementation

final Animation<double>? opacity;