ClickableText class

A clickable text wrapped inside GestureDetector Very useful to make a link inside a bloc of text

Inheritance

Constructors

ClickableText(String data, {Key? key, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, GestureTapCallback? onTap, GestureTapUpCallback? onTapUp, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel, GestureTapCallback? onDoubleTap, GestureTapDownCallback? onDoubleTapDown, GestureTapCancelCallback? onDoubleTapCancel, GestureLongPressCallback? onLongPress, GestureLongPressDownCallback? onLongPressDown, GestureLongPressCancelCallback? onLongPressCancel, GestureLongPressStartCallback? onLongPressStart, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate})
const

Properties

data String
The text to display
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale Locale?
Used to select a font when the same Unicode character can be rendered differently, depending on the locale.
final
maxLines int?
An optional maximum number of lines for the text to span, wrapping if necessary. If the text exceeds the given number of lines, it will be truncated according to overflow.
final
onDoubleTap GestureTapCallback?
The user has tapped the screen with a primary button at the same location twice in quick succession.
final
onDoubleTapCancel GestureTapCancelCallback?
The pointer that previously triggered onDoubleTapDown will not end up causing a double tap.
final
onDoubleTapDown GestureTapDownCallback?
A pointer that might cause a double tap has contacted the screen at a particular location.
final
onLongPress GestureLongPressCallback?
Called when a long press gesture with a primary button has been recognized.
final
onLongPressCancel GestureLongPressCancelCallback?
A pointer that previously triggered onLongPressDown will not end up causing a long-press.
final
onLongPressDown GestureLongPressDownCallback?
The pointer has contacted the screen with a primary button, which might be the start of a long-press.
final
onLongPressEnd GestureLongPressEndCallback?
A pointer that has triggered a long-press with a primary button has stopped contacting the screen.
final
onLongPressMoveUpdate GestureLongPressMoveUpdateCallback?
A pointer has been drag-moved after a long-press with a primary button.
final
onLongPressStart GestureLongPressStartCallback?
Called when a long press gesture with a primary button has been recognized.
final
onLongPressUp GestureLongPressUpCallback?
A pointer that has triggered a long-press with a primary button has stopped contacting the screen.
final
onTap GestureTapCallback?
A tap with a primary button has occurred.
final
onTapCancel GestureTapCancelCallback?
The pointer that previously triggered onTapDown will not end up causing a tap.
final
onTapDown GestureTapDownCallback?
A pointer that might cause a tap with a primary button has contacted the screen at a particular location.
final
onTapUp GestureTapUpCallback?
A pointer that will trigger a tap with a primary button has stopped contacting the screen at a particular location.
final
overflow TextOverflow?
How visual overflow should be handled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionColor Color?
The color to use when painting the selection.
final
semanticsLabel String?
{@template flutter.widgets.Text.semanticsLabel} An alternative semantics label for this text.
final
softWrap bool?
Whether the text should break at soft line breaks.
final
strutStyle StrutStyle?
The strut style to use. Strut style defines the strut, which sets minimum vertical layout metrics.
final
style TextStyle?
If non-null, the style to use for this text.
final
textAlign TextAlign?
How the text should be aligned horizontally.
final
textDirection TextDirection?
The directionality of the text.
final
textHeightBehavior TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
final
textScaleFactor double?
The number of font pixels for each logical pixel.
final
textWidthBasis TextWidthBasis?
Defines how to measure the width of the rendered text.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited