onTapDown property

GestureTapDownCallback? onTapDown
final

A pointer that might cause a tap with a primary button has contacted the screen at a particular location.

Implementation

final GestureTapDownCallback? onTapDown;