ClickableCard class
A clickable card wrapped inside GestureDetector
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ClickableCard
Constructors
- ClickableCard({Key? key, Widget? child, Color? color, EdgeInsetsGeometry? margin, Color? shadowColor, Color? surfaceTintColor, double? elevation, ShapeBorder? shape, bool borderOnForeground = true, bool semanticContainer = true, Clip? clipBehavior = Clip.none, GestureTapCallback? onTap, GestureTapUpCallback? onTapUp, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel, GestureTapCallback? onDoubleTap, GestureTapDownCallback? onDoubleTapDown, GestureTapCancelCallback? onDoubleTapCancel, GestureLongPressCallback? onLongPress, GestureLongPressDownCallback? onLongPressDown, GestureLongPressCancelCallback? onLongPressCancel, GestureLongPressStartCallback? onLongPressStart, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate})
-
const
Properties
- borderOnForeground → bool
-
Whether to paint the shape border in front of the child.
final
- child → Widget?
-
The card child widget
final
- clipBehavior → Clip?
-
The content will be clipped (or not) according to this option.
final
- color → Color?
-
The card's background color.
final
- elevation → double?
-
The z-coordinate at which to place this card. This controls the size of
the shadow below the card.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry?
-
The empty space that surrounds the card.
final
- onDoubleTap → GestureTapCallback?
-
The user has tapped the screen with a primary button at the same location
twice in quick succession.
final
- onDoubleTapCancel → GestureTapCancelCallback?
-
The pointer that previously triggered onDoubleTapDown will not end up
causing a double tap.
final
- onDoubleTapDown → GestureTapDownCallback?
-
A pointer that might cause a double tap has contacted the screen at a
particular location.
final
- onLongPress → GestureLongPressCallback?
-
Called when a long press gesture with a primary button has been recognized.
final
- onLongPressCancel → GestureLongPressCancelCallback?
-
A pointer that previously triggered onLongPressDown will not end up
causing a long-press.
final
- onLongPressDown → GestureLongPressDownCallback?
-
The pointer has contacted the screen with a primary button, which might
be the start of a long-press.
final
- onLongPressEnd → GestureLongPressEndCallback?
-
A pointer that has triggered a long-press with a primary button has
stopped contacting the screen.
final
- onLongPressMoveUpdate → GestureLongPressMoveUpdateCallback?
-
A pointer has been drag-moved after a long-press with a primary button.
final
- onLongPressStart → GestureLongPressStartCallback?
-
Called when a long press gesture with a primary button has been recognized.
final
- onLongPressUp → GestureLongPressUpCallback?
-
A pointer that has triggered a long-press with a primary button has
stopped contacting the screen.
final
- onTap → GestureTapCallback?
-
A tap with a primary button has occurred.
final
- onTapCancel → GestureTapCancelCallback?
-
The pointer that previously triggered onTapDown will not end up causing
a tap.
final
- onTapDown → GestureTapDownCallback?
-
A pointer that might cause a tap with a primary button has contacted the
screen at a particular location.
final
- onTapUp → GestureTapUpCallback?
-
A pointer that will trigger a tap with a primary button has stopped
contacting the screen at a particular location.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticContainer → bool
-
Whether this widget represents a single semantic container, or if false
a collection of individual semantic nodes.
final
- shadowColor → Color?
-
The color to paint the shadow below the card.
final
- shape → ShapeBorder?
-
The shape of the card's Material.
final
- surfaceTintColor → Color?
-
The color used as an overlay on color to indicate elevation.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited